@@ -109,12 +109,12 @@ KCHMMainWindow::KCHMMainWindow()
 #endif /* defined (ENABLE_AUTOTEST_SUPPORT) */
 
 	TQAccel * accel = new TQAccel( this );
-	accel->connectItem ( accel->insertItem ( Key_F11 ), this, TQT_SLOT ( slotToggleFullScreenMode() ) );
-	accel->connectItem ( accel->insertItem ( CTRL + Key_1), this, TQT_SLOT ( slotActivateContentTab() ) );
-	accel->connectItem ( accel->insertItem ( CTRL + Key_2), this, TQT_SLOT ( slotActivateIndexTab() ) );
-	accel->connectItem ( accel->insertItem ( CTRL + Key_3), this, TQT_SLOT ( slotActivateSearchTab() ) );
-	accel->connectItem ( accel->insertItem ( CTRL + Key_4), this, TQT_SLOT ( slotActivateBookmarkTab() ) );
-	accel->connectItem ( accel->insertItem ( Key_F3 ), m_searchToolbar, TQT_SLOT ( onBtnNextSearchResult() ) );
+	accel->connectItem ( accel->insertItem ( Key_F11 ), this, TQ_SLOT ( slotToggleFullScreenMode() ) );
+	accel->connectItem ( accel->insertItem ( CTRL + Key_1), this, TQ_SLOT ( slotActivateContentTab() ) );
+	accel->connectItem ( accel->insertItem ( CTRL + Key_2), this, TQ_SLOT ( slotActivateIndexTab() ) );
+	accel->connectItem ( accel->insertItem ( CTRL + Key_3), this, TQ_SLOT ( slotActivateSearchTab() ) );
+	accel->connectItem ( accel->insertItem ( CTRL + Key_4), this, TQ_SLOT ( slotActivateBookmarkTab() ) );
+	accel->connectItem ( accel->insertItem ( Key_F3 ), m_searchToolbar, TQ_SLOT ( onBtnNextSearchResult() ) );
 
 	statusBar()->show();
 	setIcon( *gIconStorage.getApplicationIcon() );
@@ -474,7 +474,7 @@ void KCHMMainWindow::setupToolbarsAndMenu( )
 				i18n( "Open File" ), 
 				TQString(),
 				this, 
-				TQT_SLOT( slotOpenMenuItemActivated() ),
+				TQ_SLOT( slotOpenMenuItemActivated() ),
 				toolbar);
 	
 	TQString fileOpenText = i18n( "Click this button to open an existing chm file." );
@@ -485,7 +485,7 @@ void KCHMMainWindow::setupToolbarsAndMenu( )
 				i18n( "Print File" ),
 				TQString(),
 				this,
-				TQT_SLOT( slotPrintMenuItemActivated() ),
+				TQ_SLOT( slotPrintMenuItemActivated() ),
 				toolbar);
 
 	TQString filePrintText = i18n( "Click this button to print the current page");
@@ -496,30 +496,30 @@ void KCHMMainWindow::setupToolbarsAndMenu( )
 	menuBar()->insertItem( i18n( "&File"), file );
 
     int id;
-	id = file->insertItem ( iconFileOpen, i18n( "&Open..."), this, TQT_SLOT( slotOpenMenuItemActivated() ), CTRL+Key_O );
+	id = file->insertItem ( iconFileOpen, i18n( "&Open..."), this, TQ_SLOT( slotOpenMenuItemActivated() ), CTRL+Key_O );
 	file->TQMenuData::setWhatsThis( id, fileOpenText );
 
-	id = file->insertItem( iconFilePrint, i18n( "&Print..."), this, TQT_SLOT( slotPrintMenuItemActivated() ), CTRL+Key_P );
+	id = file->insertItem( iconFilePrint, i18n( "&Print..."), this, TQ_SLOT( slotPrintMenuItemActivated() ), CTRL+Key_P );
 	file->TQMenuData::setWhatsThis( id, filePrintText );
 
 	file->insertSeparator();
-	id = file->insertItem ( i18n( "E&xtract CHM content..."), this, TQT_SLOT( slotExtractCHM() ) );
+	id = file->insertItem ( i18n( "E&xtract CHM content..."), this, TQ_SLOT( slotExtractCHM() ) );
 	file->TQMenuData::setWhatsThis( id, i18n( "Click this button to extract the whole CHM file content into a specific directory") );
 	file->insertSeparator();
 	
 	m_menuHistory = new KTQPopupMenu( file );
-	connect ( m_menuHistory, TQT_SIGNAL( activated(int) ), this, TQT_SLOT ( slotHistoryMenuItemActivated(int) ));
+	connect ( m_menuHistory, TQ_SIGNAL( activated(int) ), this, TQ_SLOT ( slotHistoryMenuItemActivated(int) ));
 	
 	file->insertItem( i18n( "&Recent files"), m_menuHistory );
 	
 	file->insertSeparator();
-	file->insertItem( i18n( "&Quit"), tqApp, TQT_SLOT( closeAllWindows() ), CTRL+Key_Q );
+	file->insertItem( i18n( "&Quit"), tqApp, TQ_SLOT( closeAllWindows() ), CTRL+Key_Q );
 
 	KTQPopupMenu * menu_edit = new KTQPopupMenu( this );
 	menuBar()->insertItem( i18n( "&Edit"), menu_edit );
 
-	menu_edit->insertItem ( i18n( "&Copy"), this, TQT_SLOT( slotBrowserCopy()), CTRL+Key_C );
-	menu_edit->insertItem ( i18n( "&Select all"), this, TQT_SLOT( slotBrowserSelectAll()), CTRL+Key_A );
+	menu_edit->insertItem ( i18n( "&Copy"), this, TQ_SLOT( slotBrowserCopy()), CTRL+Key_C );
+	menu_edit->insertItem ( i18n( "&Select all"), this, TQ_SLOT( slotBrowserSelectAll()), CTRL+Key_A );
 
     menu_edit->insertSeparator();
 	
@@ -537,16 +537,16 @@ void KCHMMainWindow::setupToolbarsAndMenu( )
 	
 	KTQPopupMenu * settings = new KTQPopupMenu( this );
 	menuBar()->insertItem( i18n( "&Settings"), settings );
-	settings->insertItem( i18n( "&Change settings..."), this, TQT_SLOT( slotChangeSettingsMenuItemActivated() ));
+	settings->insertItem( i18n( "&Change settings..."), this, TQ_SLOT( slotChangeSettingsMenuItemActivated() ));
 
 #if defined(USE_KDE)
 	TQPopupMenu *help = helpMenu( m_aboutDlgMenuText );
 #else
     KTQPopupMenu * help = new KTQPopupMenu( this );
-	help->insertItem( i18n( "&About"), this, TQT_SLOT( slotAboutMenuItemActivated() ), Key_F1 );
-	help->insertItem( i18n( "About &TQt"), this, TQT_SLOT( slotAboutQtMenuItemActivated() ));
+	help->insertItem( i18n( "&About"), this, TQ_SLOT( slotAboutMenuItemActivated() ), Key_F1 );
+	help->insertItem( i18n( "About &TQt"), this, TQ_SLOT( slotAboutQtMenuItemActivated() ));
 	help->insertSeparator();
-	help->insertItem( i18n( "What's &This"), this, TQT_SLOT(whatsThis()), SHIFT+Key_F1 );
+	help->insertItem( i18n( "What's &This"), this, TQ_SLOT(whatsThis()), SHIFT+Key_F1 );
 #endif
 		
 	menuBar()->insertItem( i18n( "&Help"), help );
@@ -916,14 +916,14 @@ void KCHMMainWindow::showOrHideContextWindow( int tabindex )
 			
 			// Handle clicking on m_contentsWindow element
 			connect( m_contentsWindow, 
-					 TQT_SIGNAL( clicked( TQListViewItem* ) ), 
+					 TQ_SIGNAL( clicked( TQListViewItem* ) ), 
 					 this, 
-					 TQT_SLOT( slotOnTreeClicked( TQListViewItem* ) ) );
+					 TQ_SLOT( slotOnTreeClicked( TQListViewItem* ) ) );
 			
 			connect( m_contentsWindow, 
-					 TQT_SIGNAL( doubleClicked ( TQListViewItem *, const TQPoint &, int ) ), 
+					 TQ_SIGNAL( doubleClicked ( TQListViewItem *, const TQPoint &, int ) ), 
 					 this, 
-					 TQT_SLOT( slotOnTreeDoubleClicked ( TQListViewItem *, const TQPoint &, int ) ) );
+					 TQ_SLOT( slotOnTreeDoubleClicked ( TQListViewItem *, const TQPoint &, int ) ) );
 			
 			m_tabWidget->insertTab (m_contentsWindow, i18n( "Contents" ), tabindex);
 		}
@@ -1260,7 +1260,7 @@ void KCHMMainWindow::runAutoTest()
 		else
 			m_autoteststate = STATE_OPEN_INDEX;
 		
-		TQTimer::singleShot (500, this, TQT_SLOT(runAutoTest()) );
+		TQTimer::singleShot (500, this, TQ_SLOT(runAutoTest()) );
 		break; // allow to finish the initialization sequence
 		
 	case STATE_CONTENTS_OPENNEXTPAGE:
@@ -1272,7 +1272,7 @@ void KCHMMainWindow::runAutoTest()
 		else
 			m_autoteststate = STATE_OPEN_INDEX;
 		
-		TQTimer::singleShot (50, this, TQT_SLOT(runAutoTest()) );
+		TQTimer::singleShot (50, this, TQ_SLOT(runAutoTest()) );
 		break;
 
 	case STATE_OPEN_INDEX:
@@ -1280,7 +1280,7 @@ void KCHMMainWindow::runAutoTest()
 			m_tabWidget->setCurrentPage (1);
 		
 		m_autoteststate = STATE_SHUTDOWN;
-		TQTimer::singleShot (500, this, TQT_SLOT(runAutoTest()) );
+		TQTimer::singleShot (500, this, TQ_SLOT(runAutoTest()) );
 		break;
 
 	case STATE_SHUTDOWN:
